Add data to an existing plot or create a new one
Details
Used to add raw data or summary statistics to the plot of a distribution. The height of Y is arbitrary, and can be set to optimize visualization. If SE estimates are available, the SE will be plotted
Examples
if (FALSE) { # \dontrun{
trait.data <- data.frame(Y = c(1, 2), se = c(1,2))
plot_data(trait.data, base.plot = NULL, ymax = 10)
} # }